View source: R/abi_julia_interface.R
| init_julia_env | R Documentation |
Initializes the Julia environment for ABI methods. This function is reentrant and will only perform initialization once per R session.
init_julia_env()
Invisibly returns TRUE if initialization was performed, FALSE if already initialized.
This function is not thread-safe. It assumes the caller is the main thread. All callers should document the Julia initialization side effect in their docstrings.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.