View source: R/simulation_output.R
| load_simulation_output | R Documentation |
This function reconstructs a eam_simulation_output object from a previously saved simulation output directory.
load_simulation_output(output_dir)
output_dir |
The directory containing the simulation results and config |
A eam_simulation_output object
# Load simulation output from package data
sim_output_path <- system.file(
"extdata", "rdm_minimal", "simulation",
package = "eam"
)
sim_output <- load_simulation_output(sim_output_path)
# Access the configuration
sim_output$simulation_config
# Access the dataset (check arrow documentation for working with the dataset)
dataset <- sim_output$open_dataset()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.