map_by_condition.parallel.heuristic: Heuristic to determine if parallel processing should be used

View source: R/simulation_output.R

map_by_condition.parallel.heuristicR Documentation

Heuristic to determine if parallel processing should be used

Description

Heuristic to determine if parallel processing should be used

Usage

map_by_condition.parallel.heuristic(chunk_indices)

Arguments

chunk_indices

Vector of chunk indices

Value

Logical value indicating whether to use parallel processing


eam documentation built on March 29, 2026, 5:07 p.m.