| resolve_symbol | R Documentation |
This function evaluates an expression in a given environment.
resolve_symbol(expr, env, n)
expr |
An expression to evaluate |
env |
An environment to evaluate the expression in |
n |
The number of values to generate if the expression is a distribution |
The evaluated value as it is, no assumption on its type
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.