| summarise_by_impl | R Documentation |
Internal function to perform the core summarise_by logic
summarise_by_impl(.data, dots, .by, .wider_by)
.data |
A data frame to summarise |
dots |
Quosures containing the summary expressions |
.by |
Character vector of column names to group by |
.wider_by |
Character vector of column names to keep as identifying columns |
A data frame with class "eam_summarise_by_tbl"
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.