View source: R/abc_posterior.R
| abc_posterior_bootstrap | R Documentation |
Bootstrap resample ABC posterior samples
abc_posterior_bootstrap(abc_result, n_samples, replace = TRUE)
abc_result |
An abc object from |
n_samples |
Number of bootstrap samples to draw (default 1000) |
replace |
Logical, whether to sample with replacement (default TRUE) |
Data frame of bootstrapped parameter values
# Load an example abc output, you should generate it by applying ABC to your data
# check abc_abc for details on fitting ABC models
rdm_minimal_example <- system.file("extdata", "rdm_minimal", package = "eam")
abc_model <- readRDS(file.path(rdm_minimal_example, "abc", "abc_neuralnet_model.rds"))
# Bootstrap resample posterior parameters
posterior_params <- abc_posterior_bootstrap(
abc_model,
n_samples = 100
)
# View the first few rows of the bootstrapped posterior parameters
head(posterior_params)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.