View source: R/simulation_chunk_result_flatten.R
| calculate_total_rows | R Documentation |
This function counts the total number of items across all conditions and trials to determine the size needed for pre-allocation.
calculate_total_rows(sim_results, first_trial_col)
sim_results |
The output from run_simulation(), a list of conditions |
first_trial_col |
Name of the first trial column to use for counting |
Integer, total number of rows needed
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.