evaluate_with_dt: Evaluate a list of formulas sequentially with data

View source: R/simulation.R

evaluate_with_dtR Documentation

Evaluate a list of formulas sequentially with data

Description

This function evaluates a list of formulas sequentially, allowing later formulas to reference

Usage

evaluate_with_dt(formulas, data = list(), n)

Arguments

formulas

A list of formulas to evaluate

data

A list of named values to use as the initial environment

n

The number of values to generate for each formula

Value

A named list of evaluated values with length n


eam documentation built on March 29, 2026, 5:07 p.m.

Related to evaluate_with_dt in eam...