View source: R/simulation_chunk_result_flatten.R
| fill_data_table | R Documentation |
This function fills the pre-allocated data.table vectors with data from simulation results, iterating through all conditions and trials.
fill_data_table(
sim_results,
dt_lists,
trial_col_names,
cond_param_names,
first_trial_col
)
sim_results |
The output from run_simulation(), a list of conditions |
dt_lists |
Named list of pre-allocated vectors for each column |
trial_col_names |
Character vector of trial column names |
cond_param_names |
Character vector of condition parameter names |
first_trial_col |
Name of the first trial column to use for item counting |
Named list of filled vectors ready for data.table creation
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.