View source: R/plot_accuracy.R
| plot_accuracy_ddm | R Documentation |
Calculates hit rate (proportion of trials with choice == 1) across all possible trial combinations. For simulated data, expands grid based on simulation config parameters and left joins with actual simulation results. For observed data, assumes data is already in the correct format.
plot_accuracy_ddm(
simulated_output,
observed_df,
x = "item_idx",
facet_x = c(),
facet_y = c()
)
simulated_output |
Simulation output object |
observed_df |
Observed data frame (already expanded with all trial combinations) |
x |
Variable for x-axis |
facet_x |
Variables for faceting columns |
facet_y |
Variables for faceting rows |
A ggplot2 object
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.