View source: R/simulation_chunk_result_flatten.R
| preallocate_columns | R Documentation |
This function creates pre-allocated vectors for all columns in the final data.table, determining data types from the first trial and condition.
preallocate_columns(sim_results, trial_col_names, cond_param_names, total_rows)
sim_results |
The output from run_simulation(), a list of conditions |
trial_col_names |
Character vector of trial column names |
cond_param_names |
Character vector of condition parameter names |
total_rows |
Integer, total number of rows to pre-allocate |
Named list of pre-allocated vectors for each column
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.