This function creates pre-allocated vectors for all columns in the final data.table, determining data types from the first trial and condition.
preallocate_columns(sim_results, trial_col_names, cond_param_names, total_rows)Named list of pre-allocated vectors for each column
The output from run_simulation(), a list of conditions
Character vector of trial column names
Character vector of condition parameter names
Integer, total number of rows to pre-allocate