View source: R/simulation_router.R
| route_model_to_backend | R Documentation |
This function uses a registry of backend detectors to determine which backend implementation should handle the given configuration. Each detector examines the config and returns a backend name if it can handle it, or NULL otherwise. This design pattern (Chain of Responsibility) makes it easy to add new backends without modifying this routing function.
route_model_to_backend(config)
config |
A list containing simulation configuration parameters |
The modified config list with added 'backend' parameter
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.